#
# spec file for package qt6-httpserver
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.9.1
%define short_version 6.9
%define tar_name qthttpserver-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor docs%{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-httpserver%{?pkg_suffix}
Version:        6.9.1
Release:        1.1
Summary:        Qt HTTP Server
License:        GPL-3.0-only
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Concurrent) = %{real_version}
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6CorePrivate) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6Network) = %{real_version}
BuildRequires:  cmake(Qt6NetworkPrivate) = %{real_version}
BuildRequires:  cmake(Qt6WebSockets) = %{real_version}
BuildRequires:  cmake(Qt6WebSocketsPrivate) = %{real_version}
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
QHttpServer is a simplified API for QAbstractHttpServer and QHttpServerRouter

%if !%{qt6_docs_flavor}

%package -n libQt6HttpServer6
Summary:        Qt 6 HttpServer library

%description -n libQt6HttpServer6
QHttpServer is a simplified API for QAbstractHttpServer and QHttpServerRouter.

%package -n qt6-httpserver-devel
Summary:        Qt 6 HttpServer library - Development files
Requires:       libQt6HttpServer6 = %{version}
Requires:       cmake(Qt6Network) = %{real_version}
Requires:       cmake(Qt6WebSockets) = %{real_version}

%description -n qt6-httpserver-devel
Development files for the Qt 6 HttpServer library.

%package -n qt6-httpserver-private-devel
Summary:        Non-ABI stable API for the Qt 6 HttpServer Library
Requires:       cmake(Qt6CorePrivate) = %{real_version}
Requires:       cmake(Qt6HttpServer) = %{real_version}
Requires:       cmake(Qt6NetworkPrivate) = %{real_version}
Requires:       cmake(Qt6WebSocketsPrivate) = %{real_version}

%description -n qt6-httpserver-private-devel
This package provides private headers of libQt6HttpServer that do not have any
ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

%ldconfig_scriptlets -n libQt6HttpServer6

%files -n libQt6HttpServer6
%license LICENSES/*
%{_qt6_libdir}/libQt6HttpServer.so.*

%files -n qt6-httpserver-devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtHttpServerTestsConfig.cmake
%{_qt6_cmakedir}/Qt6HttpServer/
%{_qt6_descriptionsdir}/HttpServer.json
%{_qt6_includedir}/QtHttpServer/
%{_qt6_libdir}/libQt6HttpServer.prl
%{_qt6_libdir}/libQt6HttpServer.so
%{_qt6_metatypesdir}/qt6httpserver_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_httpserver.pri
%{_qt6_pkgconfigdir}/Qt6HttpServer.pc
%exclude %{_qt6_includedir}/QtHttpServer/%{real_version}

%files -n qt6-httpserver-private-devel
%{_qt6_cmakedir}/Qt6HttpServerPrivate/
%{_qt6_includedir}/QtHttpServer/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_httpserver_private.pri

%endif

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.9.1:
  * https://www.qt.io/blog/qt-6.9.1-released
* Wed Apr  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0:
  * https://www.qt.io/blog/qt-6.9-released
* Fri Jan 31 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.8.2
  https://www.qt.io/blog/qt-6.8.2-released
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Mon Jul 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Initial package
